@@ -20,6 +20,9 @@ struct Zero {
   template<class A, class B>
   using Replace = Zero<DIM>;
 
+  template<class A1, class B1, class A2, class B2>
+  using ReplaceVars2 = Zero<DIM>;
+
   using AllTypes = univpack<Zero<DIM>>;
 
   template < int CAT >      // Whatever CAT...
